labelTextStyle property
The style for the widget label The default is black color, and fontWeight of W600
Implementation
final TextStyle? labelTextStyle;
The style for the widget label The default is black color, and fontWeight of W600
final TextStyle? labelTextStyle;