timeFormatter property

String Function(int seconds)? timeFormatter
final

The formatter for the time string By default, no formatting is applied and the time is displayed in number of seconds left

Implementation

final String Function(int seconds)? timeFormatter;