timeTextStyle property
The style for the remaining time indicator The default is black color, and fontWeight of W600
Implementation
final TextStyle? timeTextStyle;
The style for the remaining time indicator The default is black color, and fontWeight of W600
final TextStyle? timeTextStyle;